==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VaultSecretGroupArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VaultSecretGroupArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a set of certificates which are all in the same Key Vault.
 * @property sourceVault The relative URL of the Key Vault containing all of the certificates in VaultCertificates.
 * @property vaultCertificates The list of key vault references in SourceVault which contain certificates.
 */
public data class VaultSecretGroupArgs(
    public val sourceVault: Output<SubResourceArgs>? = null,
    public val vaultCertificates: Output<List<VaultCertificateArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VaultSecretGroupArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.VaultSecretGroupArgs =
        com.pulumi.azurenative.compute.inputs.VaultSecretGroupArgs.builder()
            .sourceVault(sourceVault?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .vaultCertificates(
                vaultCertificates?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VaultSecretGroupArgs].
 */
@PulumiTagMarker
public class VaultSecretGroupArgsBuilder internal constructor() {
    private var sourceVault: Output<SubResourceArgs>? = null

    private var vaultCertificates: Output<List<VaultCertificateArgs>>? = null

    /**
     * @param value The relative URL of the Key Vault containing all of the certificates in VaultCertificates.
     */
    @JvmName("ocjtimlvrxfcijxa")
    public suspend fun sourceVault(`value`: Output<SubResourceArgs>) {
        this.sourceVault = value
    }

    /**
     * @param value The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("owrrlqmwyqvpayfl")
    public suspend fun vaultCertificates(`value`: Output<List<VaultCertificateArgs>>) {
        this.vaultCertificates = value
    }

    @JvmName("bfeigamoliuydkar")
    public suspend fun vaultCertificates(vararg values: Output<VaultCertificateArgs>) {
        this.vaultCertificates = Output.all(values.asList())
    }

    /**
     * @param values The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("jnctoyyyelisedgd")
    public suspend fun vaultCertificates(values: List<Output<VaultCertificateArgs>>) {
        this.vaultCertificates = Output.all(values)
    }

    /**
     * @param value The relative URL of the Key Vault containing all of the certificates in VaultCertificates.
     */
    @JvmName("pcyhoftqqkmotsgx")
    public suspend fun sourceVault(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceVault = mapped
    }

    /**
     * @param argument The relative URL of the Key Vault containing all of the certificates in VaultCertificates.
     */
    @JvmName("mlvkeiitavvultew")
    public suspend fun sourceVault(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sourceVault = mapped
    }

    /**
     * @param value The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("dxcoeusroclqvcmk")
    public suspend fun vaultCertificates(`value`: List<VaultCertificateArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vaultCertificates = mapped
    }

    /**
     * @param argument The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("drycisttitqbrdxg")
    public suspend
    fun vaultCertificates(argument: List<suspend VaultCertificateArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VaultCertificateArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.vaultCertificates = mapped
    }

    /**
     * @param argument The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("jjgymxyrfiteqomx")
    public suspend fun vaultCertificates(
        vararg
        argument: suspend VaultCertificateArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VaultCertificateArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.vaultCertificates = mapped
    }

    /**
     * @param argument The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("fdxcirqaoqaytont")
    public suspend fun vaultCertificates(argument: suspend VaultCertificateArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VaultCertificateArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.vaultCertificates = mapped
    }

    /**
     * @param values The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("eityuchfpovtcpjo")
    public suspend fun vaultCertificates(vararg values: VaultCertificateArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vaultCertificates = mapped
    }

    internal fun build(): VaultSecretGroupArgs = VaultSecretGroupArgs(
        sourceVault = sourceVault,
        vaultCertificates = vaultCertificates,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/inputs/VaultSecretGroupArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.inputs

import com.pulumi.azurenative.compute.inputs.VaultSecretGroupArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a set of certificates which are all in the same Key Vault.
 * @property sourceVault The relative URL of the Key Vault containing all of the certificates in VaultCertificates.
 * @property vaultCertificates The list of key vault references in SourceVault which contain certificates.
 */
public data class VaultSecretGroupArgs(
    public val sourceVault: Output<SubResourceArgs>? = null,
    public val vaultCertificates: Output<List<VaultCertificateArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.compute.inputs.VaultSecretGroupArgs> {
    override fun toJava(): com.pulumi.azurenative.compute.inputs.VaultSecretGroupArgs =
        com.pulumi.azurenative.compute.inputs.VaultSecretGroupArgs.builder()
            .sourceVault(sourceVault?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .vaultCertificates(
                vaultCertificates?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VaultSecretGroupArgs].
 */
@PulumiTagMarker
public class VaultSecretGroupArgsBuilder internal constructor() {
    private var sourceVault: Output<SubResourceArgs>? = null

    private var vaultCertificates: Output<List<VaultCertificateArgs>>? = null

    /**
     * @param value The relative URL of the Key Vault containing all of the certificates in VaultCertificates.
     */
    @JvmName("kastvgauixqwelws")
    public suspend fun sourceVault(`value`: Output<SubResourceArgs>) {
        this.sourceVault = value
    }

    /**
     * @param value The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("jtgsuofovsktntld")
    public suspend fun vaultCertificates(`value`: Output<List<VaultCertificateArgs>>) {
        this.vaultCertificates = value
    }

    @JvmName("wocccspkivclvpbt")
    public suspend fun vaultCertificates(vararg values: Output<VaultCertificateArgs>) {
        this.vaultCertificates = Output.all(values.asList())
    }

    /**
     * @param values The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("gvqbunnhwurvarbr")
    public suspend fun vaultCertificates(values: List<Output<VaultCertificateArgs>>) {
        this.vaultCertificates = Output.all(values)
    }

    /**
     * @param value The relative URL of the Key Vault containing all of the certificates in VaultCertificates.
     */
    @JvmName("maygskanvtfvbvur")
    public suspend fun sourceVault(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceVault = mapped
    }

    /**
     * @param argument The relative URL of the Key Vault containing all of the certificates in VaultCertificates.
     */
    @JvmName("rrqsmkuaftumludy")
    public suspend fun sourceVault(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sourceVault = mapped
    }

    /**
     * @param value The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("ardwybdvvmtbayjv")
    public suspend fun vaultCertificates(`value`: List<VaultCertificateArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vaultCertificates = mapped
    }

    /**
     * @param argument The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("woqchrybukavhewc")
    public suspend
    fun vaultCertificates(argument: List<suspend VaultCertificateArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VaultCertificateArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.vaultCertificates = mapped
    }

    /**
     * @param argument The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("ciloallrklrebvwb")
    public suspend fun vaultCertificates(
        vararg
        argument: suspend VaultCertificateArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VaultCertificateArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.vaultCertificates = mapped
    }

    /**
     * @param argument The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("jqixhmtborbrgotf")
    public suspend fun vaultCertificates(argument: suspend VaultCertificateArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(VaultCertificateArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.vaultCertificates = mapped
    }

    /**
     * @param values The list of key vault references in SourceVault which contain certificates.
     */
    @JvmName("juhemroesvrjhhyq")
    public suspend fun vaultCertificates(vararg values: VaultCertificateArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vaultCertificates = mapped
    }

    internal fun build(): VaultSecretGroupArgs = VaultSecretGroupArgs(
        sourceVault = sourceVault,
        vaultCertificates = vaultCertificates,
    )
}
